const EventEmitter = require('events');

class EnergyTracker extends EventEmitter{
    constructor({starting_energy, known_appliances, day_emitter}) {
        super();
        this.energy = starting_energy;
        this.known_appliances = known_appliances;
        this.installed = [];
		day_emitter.on("newday", ({mm_dd}) => {
			let daily_energy_usage = 0;
            this.installed.forEach(installed => daily_energy_usage += installed.kwh);
            this.energy -= daily_energy_usage;
            if(this.energy <= 0){
                this.energy = 0;
                this.emit("empty", this.energy);
            }
            else if(this.energy < 0.1 * starting_energy){
                this.emit("critical", this.energy);
            }
            else if(this.energy < 0.5 * starting_energy){
                this.emit("low", this.energy);
            }
            else{
                this.emit("normal", this.energy);
            }
		});
    }
    install(appliance){
        let index = this.known_appliances.map(known_appliance => known_appliance.name).indexOf(appliance);
        if(index === -1){
            console.log("Appliance Not Found");
        }
        else{
            this.installed.push(this.known_appliances[index]);
            console.log(`${appliance} installed`);
        }
    }
}

module.exports = EnergyTracker;